@@ -16,15 +16,19 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import absolute_import
 import sys
+import six
 if sys.version_info >= (2, 7):
     import unittest
 else:
     import unittest2 as unittest
 import random
-random.seed(6) ### Make sure tests are repeatable
+random.seed(6)  # Make sure tests are repeatable
 from os import path
 
+import numpy as np
+
 from nazca.utils.normalize import simplify
 import nazca.rl.aligner as alig
 import nazca.rl.blocking as blo
@@ -50,10 +54,89 @@ class AlignerTestCase(unittest.TestCase):
         processings = (GeographicalProcessing(2, 2, units='km'),)
         aligner = alig.BaseAligner(threshold=30, processings=processings)
         mat, matched = aligner.align(refset, targetset)
-        true_matched = [(0,0), (0, 2), (1,2), (3,1)]
-        for k, values in matched.iteritems():
+        true_matched = [(0, 0), (0, 2), (1, 2), (3, 1)]
+        for k, values in six.iteritems(matched):
             for v, distance in values:
-                self.assertIn((k,v), true_matched)
+                self.assertIn((k, v), true_matched)
+
+    def test_align_with_weight(self):
+        refset = [
+            ['V1', 'l1', (6.14194444444, 48.67)],
+            ['V2', 'l2', (6.2, 49)],
+            ['V3', 'l3', (5.1, 48)],
+            ['V4', 'l4', (5.2, 48.1)],
+        ]
+        targetset = [
+            ['T1', 'l1', (6.17, 48.7)],
+            ['T2', 'l1', (6.14, 48.73)],
+            ['T3', 'l4', (6.25, 48.91)],
+        ]
+
+        ref_indexes = range(len(refset))
+        target_indexes = range(len(targetset))
+
+        # Compute the distance matrix on the label only (weight=1)
+        aligner = alig.BaseAligner(
+            threshold=0.2,
+            processings=(LevenshteinProcessing(1, 1), ),
+        )
+        mat_difflib = aligner.compute_distance_matrix(
+            refset,
+            targetset,
+            ref_indexes,
+            target_indexes,
+        )
+
+        # Compute the distance matrix on the location only (weight=1)
+        aligner = alig.BaseAligner(
+            threshold=0.2,
+            processings=(GeographicalProcessing(2, 2), )
+        )
+        mat_geo = aligner.compute_distance_matrix(
+            refset,
+            targetset,
+            ref_indexes,
+            target_indexes,
+        )
+
+        # Compute the distance matrix with label and location (same weight)
+        aligner = alig.BaseAligner(
+            threshold=0.2,
+            processings=(
+                LevenshteinProcessing(1, 1),
+                GeographicalProcessing(2, 2),
+            )
+        )
+        mat_difflib_geo = aligner.compute_distance_matrix(
+            refset,
+            targetset,
+            ref_indexes,
+            target_indexes,
+        )
+
+        np.testing.assert_almost_equal(mat_difflib_geo, mat_geo + mat_difflib)
+
+        # Same aligner, but the processings have ≠ weights, to show that the
+        # weight is taken into account in the final result
+        aligner = alig.BaseAligner(
+            threshold=0.2,
+            processings=(
+                LevenshteinProcessing(1, 1, weight=0.8),
+                GeographicalProcessing(2, 2, weight=0.2),
+            )
+        )
+        mat_difflib_geo = aligner.compute_distance_matrix(
+            refset,
+            targetset,
+            ref_indexes,
+            target_indexes,
+        )
+
+        np.testing.assert_almost_equal(
+            mat_difflib_geo,
+            0.2*mat_geo + 0.8*mat_difflib
+        )
+
 
     def test_blocking_align(self):
         refset = [['V1', 'label1', (6.14194444444, 48.67)],
@@ -66,7 +149,7 @@ class AlignerTestCase(unittest.TestCase):
                      ['T3', 'labelt3', (6.25, 48.91)],
                      ]
         # Creation of the aligner object
-        true_matched = set([(0,0), (0, 2), (1,2), (3,1)])
+        true_matched = set([(0, 0), (0, 2), (1, 2), (3, 1)])
         processings = (GeographicalProcessing(2, 2, units='km'),)
         aligner = alig.BaseAligner(threshold=30, processings=processings)
         blocking = blo.KdTreeBlocking(ref_attr_index=2,
@@ -76,7 +159,7 @@ class AlignerTestCase(unittest.TestCase):
         predict_matched = set()
         for alignind, targetind in blocking.iter_indice_blocks():
             mat, matched = aligner._get_match(refset, targetset, alignind, targetind)
-            for k, values in matched.iteritems():
+            for k, values in six.iteritems(matched):
                 for v, distance in values:
                     predict_matched.add((k, v))
         self.assertEqual(true_matched, predict_matched)
@@ -92,7 +175,7 @@ class AlignerTestCase(unittest.TestCase):
                      ['T3', 'labelt3', (6.25, 48.91)],
                      ]
         # Creation of the aligner object
-        true_matched = set([(0,0), (0, 2), (1,2), (3,1)])
+        true_matched = set([(0, 0), (0, 2), (1, 2), (3, 1)])
         processings = (GeographicalProcessing(2, 2, units='km'),)
         aligner = alig.BaseAligner(threshold=30, processings=processings)
         aligner.register_blocking(blo.KdTreeBlocking(ref_attr_index=2,
@@ -100,17 +183,17 @@ class AlignerTestCase(unittest.TestCase):
                                                      threshold=0.3))
         global_mat, global_matched = aligner.align(refset, targetset)
         predict_matched = set()
-        for k, values in global_matched.iteritems():
+        for k, values in six.iteritems(global_matched):
             for v, distance in values:
                 predict_matched.add((k, v))
         self.assertEqual(true_matched, predict_matched)
 
     def test_unique_align(self):
         refset = [['V1', 'label1', (6.14194444444, 48.67)],
-                    ['V2', 'label2', (6.2, 49)],
-                    ['V3', 'label3', (5.1, 48)],
-                    ['V4', 'label4', (5.2, 48.1)],
-                    ]
+                  ['V2', 'label2', (6.2, 49)],
+                  ['V3', 'label3', (5.1, 48)],
+                  ['V4', 'label4', (5.2, 48.1)],
+                  ]
         targetset = [['T1', 'labelt1', (6.17, 48.7)],
                      ['T2', 'labelt2', (5.3, 48.2)],
                      ['T3', 'labelt3', (6.25, 48.91)],
@@ -181,8 +264,5 @@ class PipelineAlignerTestCase(unittest.TestCase):
             self.assertIn(m, matched_wo_distance)
 
 
-
-
 if __name__ == '__main__':
     unittest.main()
-
