@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import absolute_import
 import sys
 if sys.version_info >= (2, 7):
     import unittest
@@ -24,10 +25,10 @@ else:
 from os import path
 from functools import partial
 import random
-random.seed(6) ### Make sure tests are repeatable / Minhashing
+random.seed(6)  # Make sure tests are repeatable / Minhashing
 
-from nazca.utils.distances import (levenshtein, soundex, soundexcode,   \
-                                       jaccard, euclidean, geographical)
+from nazca.utils.distances import (levenshtein, soundex, soundexcode,
+                                   jaccard, euclidean, geographical)
 from nazca.rl.blocking import (KeyBlocking, SortedNeighborhoodBlocking,
                                MergeBlocking,
                                NGramBlocking, PipelineBlocking,
@@ -200,7 +201,7 @@ class NGramBlockingTest(unittest.TestCase):
                      ['d', 'ccdd', 'bbaa']]
         true_pairs = [('3', 'c'), ('4', 'd')]
         blocking = NGramBlocking(ref_attr_index=2, target_attr_index=2,
-                                   ngram_size=2, depth=1)
+                                 ngram_size=2, depth=1)
         blocking.fit(refset, targetset)
         pairs = list(blocking.iter_id_pairs())
         self.assertEqual(len(pairs), len(true_pairs))
@@ -224,7 +225,7 @@ class SortedNeighborhoodBlockingTest(unittest.TestCase):
         """ Test sort reversing values
         """
         blocking = SortedNeighborhoodBlocking(ref_attr_index=1, target_attr_index=1,
-                                              key_func=lambda x:x[::-1], window_width=1)
+                                              key_func=lambda x: x[::-1], window_width=1)
         blocking.fit(SOUNDEX_REFSET, SOUNDEX_TARGETSET)
         blocks = list(blocking.iter_id_blocks())
         true_blocks = [(['a1'], ['b3']), (['a2'], ['b6']), (['a5'], ['b4']), (['a3'], ['b7', 'b1']),
@@ -236,10 +237,9 @@ class SortedNeighborhoodBlockingTest(unittest.TestCase):
 
 class MergeBlockingTest(unittest.TestCase):
 
-
     def test_merge_blocks(self):
         blocking = MergeBlocking(ref_attr_index=1, target_attr_index=None,
-                                 score_func=lambda x:x[2])
+                                 score_func=lambda x: x[2])
         refset = [('http://fr.wikipedia.org/wiki/Paris_%28Texas%29', 'Paris', 25898),
                   ('http://fr.wikipedia.org/wiki/Paris', 'Paris', 12223100),
                   ('http://fr.wikipedia.org/wiki/Saint-Malo', 'Saint-Malo', 46342)]
@@ -257,7 +257,7 @@ class MergeBlockingTest(unittest.TestCase):
 
     def test_merge_blocks_targetset(self):
         blocking = MergeBlocking(ref_attr_index=None, target_attr_index=2,
-                                 score_func=lambda x:x[1])
+                                 score_func=lambda x: x[1])
         refset = [('Paris (Texas)', 25000),
                   ('Paris (France)', 12000000)]
         targetset = [('http://fr.wikipedia.org/wiki/Paris_%28Texas%29', 25898, 'Paris'),
@@ -278,10 +278,10 @@ class KmeansBlockingTest(unittest.TestCase):
 
     def test_clustering_blocking_kmeans(self):
         refset = [['V1', 'label1', (6.14194444444, 48.67)],
-                    ['V2', 'label2', (6.2, 49)],
-                    ['V3', 'label3', (5.1, 48)],
-                    ['V4', 'label4', (5.2, 48.1)],
-                    ]
+                  ['V2', 'label2', (6.2, 49)],
+                  ['V3', 'label3', (5.1, 48)],
+                  ['V4', 'label4', (5.2, 48.1)],
+                  ]
         targetset = [['T1', 'labelt1', (6.2, 48.9)],
                      ['T2', 'labelt2', (5.3, 48.2)],
                      ['T3', 'labelt3', (6.25, 48.91)],
@@ -290,7 +290,7 @@ class KmeansBlockingTest(unittest.TestCase):
             import sklearn as skl
         except ImportError:
             self.skipTest('Scikit learn does not seem to be installed')
-        if int(skl.__version__.split('-')[0].split('.')[1])<=11:
+        if int(skl.__version__.split('-')[0].split('.')[1]) <= 11:
             self.skipTest('Scikit learn version is too old - Skipping test')
         blocking = KmeansBlocking(ref_attr_index=2, target_attr_index=2)
         blocking.fit(refset, targetset)
@@ -361,7 +361,8 @@ class PipelineBlockingTest(unittest.TestCase):
                      ['b', 'aabb', 'ddcc'],
                      ['c', 'ccdd', 'aabb'],
                      ['d', 'ccdd', 'bbaa']]
-        true_pairs = [((0, '1'), (0, 'a')), ((1, '2'), (1, 'b')), ((2, '3'), (2, 'c')), ((3, '4'), (3, 'd'))]
+        true_pairs = [((0, '1'), (0, 'a')), ((1, '2'), (1, 'b')),
+                      ((2, '3'), (2, 'c')), ((3, '4'), (3, 'd'))]
         blocking_1 = NGramBlocking(ref_attr_index=1, target_attr_index=1,
                                    ngram_size=2, depth=1)
         blocking_2 = NGramBlocking(ref_attr_index=2, target_attr_index=2,
@@ -395,9 +396,5 @@ class PipelineBlockingTest(unittest.TestCase):
             self.assertIn(pair, pairs)
 
 
-
-
-
 if __name__ == '__main__':
     unittest.main()
-
