@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import absolute_import
 import sys
 if sys.version_info >= (2, 7):
     import unittest
@@ -36,6 +37,7 @@ from nazca.ner.sources import NerSourceLexicon
 
 TESTDIR = path.dirname(__file__)
 
+
 @contextmanager
 def tempdir():
     try:
@@ -44,7 +46,7 @@ def tempdir():
     finally:
         try:
             shutil.rmtree(temp)
-        except:
+        except BaseException:
             pass
 
 
@@ -52,21 +54,21 @@ class ValidXHTMLPrettyPrintTest(unittest.TestCase):
 
     def test_valid(self):
         from lxml import etree
-        if int(etree.__version__< '3.2.0'):
+        if int(etree.__version__ < '3.2.0'):
             # https://bugs.launchpad.net/lxml/+bug/673205
             self.skipTest('Lxml version to old for ValidXHTMLPrettyPrint')
         self.assertTrue(ValidXHTMLPrettyPrint().is_valid(u'<p>coucou</p>'))
 
     def test_valid_unicode(self):
         from lxml import etree
-        if int(etree.__version__< '3.2.0'):
+        if int(etree.__version__ < '3.2.0'):
             # https://bugs.launchpad.net/lxml/+bug/673205
             self.skipTest('Lxml version to old for ValidXHTMLPrettyPrint')
         self.assertTrue(ValidXHTMLPrettyPrint().is_valid(u'<p>hé</p>'))
 
     def test_invalid(self):
         from lxml import etree
-        if int(etree.__version__< '3.2.0'):
+        if int(etree.__version__ < '3.2.0'):
             # https://bugs.launchpad.net/lxml/+bug/673205
             self.skipTest('Lxml version to old for ValidXHTMLPrettyPrint')
         self.assertFalse(ValidXHTMLPrettyPrint().is_valid(u'<p><div>coucou</div></p>'))
@@ -106,7 +108,7 @@ class DataIOTestCase(unittest.TestCase):
                           [3, (23, 2.17), u'cherry', u'flower']], data)
 
         data = parsefile(path.join(TESTDIR, 'data', 'file2parse'),
-                         [0, (2, 3), 4, 1], delimiter=',', formatopt={2:str})
+                         [0, (2, 3), 4, 1], delimiter=',', formatopt={2: str})
         self.assertEqual([[1, ('12', 19), u'apple', u'house'],
                           [2, ('21.9', 19), u'stramberry', u'horse'],
                           [3, ('23', 2.17), u'cherry', u'flower']], data)
@@ -117,7 +119,6 @@ class DataIOTestCase(unittest.TestCase):
                           ['2', ('21.9', '19'), 'stramberry', 'horse'],
                           ['3', ('23', '2.17'), 'cherry', 'flower']], data)
 
-
     def test_autocast(self):
         self.assertEqual(autocast('1'), 1)
         self.assertEqual(autocast('1.'), 1.)
@@ -222,34 +223,34 @@ class DataIOTestCase(unittest.TestCase):
     @unittest.skipUnless(SPARQL_ENABLED, 'python-sparqlwrapper is not installed')
     def test_sparql_autocast(self):
         alignset = sparqlquery('http://dbpedia.inria.fr/sparql',
-                                 'prefix db-owl: <http://dbpedia.org/ontology/>'
-                                 'prefix db-prop: <http://fr.dbpedia.org/property/>'
-                                 'select ?ville, ?name, ?long, ?lat where {'
-                                 ' ?ville db-owl:country <http://fr.dbpedia.org/resource/France> .'
-                                 ' ?ville rdf:type db-owl:PopulatedPlace .'
-                                 ' ?ville db-owl:populationTotal ?population .'
-                                 ' ?ville foaf:name ?name .'
-                                 ' ?ville db-prop:longitude ?long .'
-                                 ' ?ville db-prop:latitude ?lat .'
-                                 ' FILTER (?population > 1000)'
-                                 '} LIMIT 100', indexes=[0, 1, (2, 3)])
+                               'prefix db-owl: <http://dbpedia.org/ontology/>'
+                               'prefix db-prop: <http://fr.dbpedia.org/property/>'
+                               'select ?ville, ?name, ?long, ?lat where {'
+                               ' ?ville db-owl:country <http://fr.dbpedia.org/resource/France> .'
+                               ' ?ville rdf:type db-owl:PopulatedPlace .'
+                               ' ?ville db-owl:populationTotal ?population .'
+                               ' ?ville foaf:name ?name .'
+                               ' ?ville db-prop:longitude ?long .'
+                               ' ?ville db-prop:latitude ?lat .'
+                               ' FILTER (?population > 1000)'
+                               '} LIMIT 100', indexes=[0, 1, (2, 3)])
         self.assertEqual(len(alignset), 100)
         self.assertTrue(isinstance(alignset[0][2][0], float))
 
     @unittest.skipUnless(SPARQL_ENABLED, 'python-sparqlwrapper is not installed')
     def test_sparql_no_autocast(self):
         alignset = sparqlquery('http://dbpedia.inria.fr/sparql',
-                                 'prefix db-owl: <http://dbpedia.org/ontology/>'
-                                 'prefix db-prop: <http://fr.dbpedia.org/property/>'
-                                 'select ?ville, ?name, ?long, ?lat where {'
-                                 ' ?ville db-owl:country <http://fr.dbpedia.org/resource/France> .'
-                                 ' ?ville rdf:type db-owl:PopulatedPlace .'
-                                 ' ?ville db-owl:populationTotal ?population .'
-                                 ' ?ville foaf:name ?name .'
-                                 ' ?ville db-prop:longitude ?long .'
-                                 ' ?ville db-prop:latitude ?lat .'
-                                 ' FILTER (?population > 1000)'
-                                 '} LIMIT 100', indexes=[0, 1, (2, 3)], autocast_data=False)
+                               'prefix db-owl: <http://dbpedia.org/ontology/>'
+                               'prefix db-prop: <http://fr.dbpedia.org/property/>'
+                               'select ?ville, ?name, ?long, ?lat where {'
+                               ' ?ville db-owl:country <http://fr.dbpedia.org/resource/France> .'
+                               ' ?ville rdf:type db-owl:PopulatedPlace .'
+                               ' ?ville db-owl:populationTotal ?population .'
+                               ' ?ville foaf:name ?name .'
+                               ' ?ville db-prop:longitude ?long .'
+                               ' ?ville db-prop:latitude ?lat .'
+                               ' FILTER (?population > 1000)'
+                               '} LIMIT 100', indexes=[0, 1, (2, 3)], autocast_data=False)
         self.assertEqual(len(alignset), 100)
         self.assertFalse(isinstance(alignset[0][2][0], float))
 
@@ -261,4 +262,3 @@ class DataIOTestCase(unittest.TestCase):
 
 if __name__ == '__main__':
     unittest.main()
-
