@@ -16,13 +16,15 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import absolute_import
 import sys
+from six.moves import range
 if sys.version_info >= (2, 7):
     import unittest
 else:
     import unittest2 as unittest
 import random
-random.seed(6) ### Make sure tests are repeatable
+random.seed(6)  # Make sure tests are repeatable
 from dateutil import parser as dateparser
 
 from nazca.utils.distances import (levenshtein, soundex, soundexcode,
@@ -48,26 +50,26 @@ class DistancesTest(unittest.TestCase):
         self.assertEqual(levenshtein('bon', 'bonjour'), 4)
         self.assertEqual(levenshtein('Victor Hugo', 'Hugo Victor'), 0)
 
-        #Test symetry
+        # Test symetry
         self.assertEqual(levenshtein('Victor Hugo', 'Vitor Wugo'),
                          levenshtein('Vitor Wugo', 'Victor Hugo'))
 
     def test_soundex(self):
-        ##     Test extracted from Wikipedia en :
-        #Using this algorithm :
-        #both "Robert" and "Rupert" return the same string "R163"
-        #while "Rubin" yields "R150".
+        # Test extracted from Wikipedia en :
+        # Using this algorithm :
+        # both "Robert" and "Rupert" return the same string "R163"
+        # while "Rubin" yields "R150".
         #
         # "Ashcraft" and "Ashcroft" both yield "A261" and not "A226"
-        #(the chars 's' and 'c' in the name would receive a single number
-        #of 2 and not 22 since an 'h' lies in between them).
+        # (the chars 's' and 'c' in the name would receive a single number
+        # of 2 and not 22 since an 'h' lies in between them).
         #
         # "Tymczak" yields "T522" not "T520"
-        #(the chars 'z' and 'k' in the name are coded as 2 twice since a vowel
-        #lies in between them).
+        # (the chars 'z' and 'k' in the name are coded as 2 twice since a vowel
+        # lies in between them).
         #
-        #"Pfister" yields "P236" not "P123" (the first two letters have the same
-        #number and are coded once as 'P').
+        # "Pfister" yields "P236" not "P123" (the first two letters have the same
+        # number and are coded once as 'P').
 
         self.assertEqual(soundexcode('Robert', 'english'), 'R163')
         self.assertEqual(soundexcode('Rubert', 'english'), 'R163')
@@ -80,21 +82,21 @@ class DistancesTest(unittest.TestCase):
         self.assertEqual(soundex('Rubin', 'Robert', 'english'), 1)
 
     def test_jaccard(self):
-        #The jaccard indice between two words is the ratio of the number of
-        #identical letters and the total number of letters
-        #Each letter is counted once only
-        #The distance is 1 - jaccard_indice
+        # The jaccard indice between two words is the ratio of the number of
+        # identical letters and the total number of letters
+        # Each letter is counted once only
+        # The distance is 1 - jaccard_indice
 
         self.assertEqual(jaccard('bonjour', 'bonjour'), 0.0)
         self.assertAlmostEqual(jaccard('boujour', 'bonjour'), 1, 2)
         self.assertAlmostEqual(jaccard(u'sacré rubert', u'sacré hubert'), 0.667, 2)
 
-        #Test symetry
+        # Test symetry
         self.assertEqual(jaccard('orange', 'morange'),
                          jaccard('morange', 'orange'))
 
     def test_temporal(self):
-        #Test the distance between two dates. The distance can be given in
+        # Test the distance between two dates. The distance can be given in
         #``days``, ``months`` or ``years``
         try:
             from nazca.distances import temporal
@@ -103,21 +105,21 @@ class DistancesTest(unittest.TestCase):
         self.assertEqual(temporal('14 aout 1991', '14/08/1991'), 0)
         self.assertEqual(temporal('14 aout 1991', '08/14/1991'), 0)
         self.assertEqual(temporal('14 aout 1991', '08/15/1992'), 367)
-        #Test a case of ambiguity
+        # Test a case of ambiguity
         self.assertEqual(temporal('1er mai 2012', '01/05/2012'), 0)
         self.assertEqual(temporal('1er mai 2012', '05/01/2012', dayfirst=False), 0)
-        #Test the different granularities available
+        # Test the different granularities available
         self.assertAlmostEqual(temporal('14 aout 1991', '08/15/1992', 'years'), 1.0, 1)
         self.assertAlmostEqual(temporal('1991', '1992', 'years'), 1.0, 1)
         self.assertAlmostEqual(temporal('13 mars', '13 mai', 'months'), 2.0, 1)
         self.assertAlmostEqual(temporal('13 march', '13 may', 'months',
                                         parserinfo=dateparser.parserinfo), 2.0, 1)
 
-        #Test fuzzyness
+        # Test fuzzyness
         self.assertEqual(temporal('Jean est né le 1er octobre 1958',
                                   'Le 01-10-1958, Jean est né'), 0)
 
-        #Test symetry
+        # Test symetry
         self.assertEqual(temporal('14-08-1991', '15/08/1992'),
                          temporal('15/08/1992', '14/08/1991'))
 
@@ -126,7 +128,7 @@ class DistancesTest(unittest.TestCase):
         self.assertEqual(euclidean(-10, 11), 21)
         self.assertEqual(euclidean('-10', '11'), 21)
 
-        #Test symetry
+        # Test symetry
         self.assertEqual(euclidean(10, 11),
                          euclidean(11, 10))
 
@@ -158,8 +160,8 @@ class GeographicalTestCase(unittest.TestCase):
 
     def test_geographical_3(self):
         # Use two columns of the record
-        processing = GeographicalProcessing(ref_attr_index=(1,2),
-                                            target_attr_index=(1,2),
+        processing = GeographicalProcessing(ref_attr_index=(1, 2),
+                                            target_attr_index=(1, 2),
                                             units='km')
         _input = (('paris', 48.856578, 2.351828),
                   ('london', 51.504872, -0.07857))
@@ -204,15 +206,15 @@ class LevenshteinTestCase(unittest.TestCase):
         i1, i2 = self.input1, self.input2
         m = self.matrix
 
-        for i in xrange(len(i1)):
-            for j in xrange(len(i2)):
+        for i in range(len(i1)):
+            for j in range(len(i2)):
                 self.assertAlmostEqual(m[i, j], d(i1[i], i2[j]), 4)
 
     def test_operation(self):
         m = self.matrix
         self.assertTrue((3 * m == m * 3).all())
-        self.assertTrue(((m - 0.5*m) == (0.5 * m)).all())
-        self.assertTrue(((m + 10*m - m * 3) == (8 * m)).all())
+        self.assertTrue(((m - 0.5 * m) == (0.5 * m)).all())
+        self.assertTrue(((m + 10 * m - m * 3) == (8 * m)).all())
 
     def test_pdist(self):
         _input = [u'Victor Wugo', u'Albert Camus', 'Albert Camu']
@@ -266,4 +268,3 @@ class TemporalTestCase(unittest.TestCase):
 
 if __name__ == '__main__':
     unittest.main()
-
