@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import absolute_import
 import sys
 if sys.version_info >= (2, 7):
     import unittest
@@ -43,7 +44,14 @@ class TokenizerTest(unittest.TestCase):
                                         token_max_size=3)
         tokens = list(tokenizer)
         self.assertEqual(len(tokens), 18)
-        t1 = Token(word='Hello everyone this', start=0, end=20, sentence=Sentence(indice=0, start=0, end=38))
+        t1 = Token(
+            word='Hello everyone this',
+            start=0,
+            end=20,
+            sentence=Sentence(
+                indice=0,
+                start=0,
+                end=38))
         self.assertEqual(tokens[0], t1)
         t2 = Token(word='And', start=39, end=42, sentence=Sentence(indice=1, start=39, end=46))
         self.assertEqual(tokens[16], t2)
@@ -66,7 +74,14 @@ class TokenizerTest(unittest.TestCase):
                                         token_max_size=3)
         tokens = list(tokenizer)
         self.assertEqual(len(tokens), 10)
-        t1 =  Token(word='me speaking', start=26, end=37, sentence=Sentence(indice=0, start=0, end=38))
+        t1 = Token(
+            word='me speaking',
+            start=26,
+            end=37,
+            sentence=Sentence(
+                indice=0,
+                start=0,
+                end=38))
         self.assertEqual(tokens[8], t1)
 
     def test_richstringtokenizer_maxsize(self):
@@ -98,4 +113,3 @@ class TokenizerTest(unittest.TestCase):
 
 if __name__ == '__main__':
     unittest.main()
-
